/************************************************************
* Copyright (C) 2007 Masahiko SAWAI All Rights Reserved. 
************************************************************/

#import <AvailabilityMacros.h>
#import <IOBluetooth/objc/IOBluetoothDevice.h>

@interface IOBluetoothDevice (WiiRemote)
- (BOOL)isWiiremote;
@end
